@@ -9,9 +9,9 @@ use Complete::Common qw(:all);
 use Exporter qw(import);
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-01-17'; # DATE
+our $DATE = '2023-01-19'; # DATE
 our $DIST = 'Complete-Util'; # DIST
-our $VERSION = '0.615'; # VERSION
+our $VERSION = '0.616'; # VERSION
 
 our @EXPORT_OK = qw(
                        hashify_answer
@@ -898,8 +898,11 @@ sub complete_comma_sep_pair {
         # we should be completing values
 
         return [] unless $complete_value;
-        return $complete_value->(word=>$mentioned_elems[-1], key=>$mentioned_keys[-1]);
-
+        my $word = pop @mentioned_elems;
+        my $res = $complete_value->(word=>$word, key=>$mentioned_keys[-1]);
+        my $prefix = join($sep, @mentioned_elems);
+        $prefix .= $sep if @mentioned_elems;
+        modify_answer(answer=>$res, prefix=>$prefix);
     }
 }
 
@@ -1105,7 +1108,7 @@ Complete::Util - General completion routine
 
 =head1 VERSION
 
-This document describes version 0.615 of Complete::Util (from Perl distribution Complete-Util), released on 2023-01-17.
+This document describes version 0.616 of Complete::Util (from Perl distribution Complete-Util), released on 2023-01-19.
 
 =head1 DESCRIPTION
 
